# 🌳 Merkly

The **simple and easy** implementation of **Python Merkle Tree**

---

[![Test](https://github.com/olivmath/merkly/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/olivmath/merkly/actions/workflows/test.yml)
![GitHub last commit](https://img.shields.io/github/last-commit/olivmath/merkly)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/olivmath/merkly)

![PyPI](https://img.shields.io/pypi/v/merkly)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/merkly)
![PyPI - Downloads](https://img.shields.io/pypi/dm/merkly)
![PyPI - License](https://img.shields.io/pypi/l/merkly)

## CREDITS

[![GitHub Contributors Image](https://contrib.rocks/image?repo=olivmath/merkly)](https://github.com/olivmath/merkly/graphs/contributors)

## HOW TO INSTALL

```
poetry add merkly
```

```
pip install merkly
```

## HOW IT WORKS

This library provides a clean and easy to use implementation of the Merkle Tree with the following features:

- [x] Create Leaf
- [ ] Create Root
- [ ] Create Proof
- [ ] Validate Leafs

## CONTRIBUTING

Follow the guide of development -> [CONTRIBUTING](CONTRIBUTING.md)

## LICENSE

[MIT](LICENSE)
